@@ -18,7 +18,7 @@ class PlusMinusYearCalculator(YearCalculator):
     def getPlusMinus(cls, year: Year, **kwargs) -> dict[str, Optional[Deci]]:
         """
         Plus/Minus (+/-) is used to show the net score differential for a team in a Year.
-        
+
         Plus/Minus = ΣA - ΣB
         WHERE:
         A = All scores by a team in a Year
@@ -38,13 +38,17 @@ class PlusMinusYearCalculator(YearCalculator):
 
         teamIdAndPlusMinus = dict()
         teamIdAndPointsScored = PointsScoredYearCalculator.getPointsScored(year, **kwargs)
-        teamIdAndOpponentPointsScored = PointsScoredYearCalculator.getOpponentPointsScored(year, **kwargs)
+        teamIdAndOpponentPointsScored = PointsScoredYearCalculator.getOpponentPointsScored(
+            year, **kwargs
+        )
         for teamId in YearNavigator.getAllTeamIds(year):
             pointsScored = teamIdAndPointsScored[teamId]
             opponentPointsScored = teamIdAndOpponentPointsScored[teamId]
             if None in (pointsScored, opponentPointsScored):
                 teamIdAndPlusMinus[teamId] = None
             else:
-                teamIdAndPlusMinus[teamId] = teamIdAndPointsScored[teamId] - teamIdAndOpponentPointsScored[teamId]
+                teamIdAndPlusMinus[teamId] = (
+                    teamIdAndPointsScored[teamId] - teamIdAndOpponentPointsScored[teamId]
+                )
 
         return teamIdAndPlusMinus
