@@ -18,9 +18,9 @@ class ESPNLeagueLoader(LeagueLoader):
     Responsible for loading a League from ESPN Fantasy Football.
     https://www.espn.com/fantasy/football/
     """
+
     __ESPN_WIN_OUTCOME: str = "W"
     __ESPN_LOSS_OUTCOME: str = "L"
-    __ESPN_TIE_OUTCOME: str = "T"
     __ESPN_BYE_OUTCOME: str = "U"
     __TEAMS_IN_PLAYOFFS_TO_PLAYOFF_WEEK_COUNT_MAP: dict[int, int] = {
         2: 1,
@@ -28,10 +28,12 @@ class ESPNLeagueLoader(LeagueLoader):
         4: 2,
         6: 3,
         7: 3,
-        8: 3
+        8: 3,
     }
 
-    def __init__(self, leagueId: str, years: list[int], espnS2: str = None, swid: str = None, **kwargs):
+    def __init__(
+        self, leagueId: str, years: list[int], espnS2: str = None, swid: str = None, **kwargs
+    ):
         # validation
         try:
             int(leagueId)
@@ -42,13 +44,18 @@ class ESPNLeagueLoader(LeagueLoader):
         self.__espnS2 = espnS2
         self.__swid = swid
         self.__espnTeamIdToTeamMap: dict[str, Team] = dict()
-        self.__ownerNamesAndAliases: dict[str, list[str]] = dict()
 
     def __getAllLeagues(self) -> list[ESPNLeague]:
         espnLeagueYears = list()
         for year in self._years:
             espnLeagueYears.append(
-                espn.League(league_id=int(self._leagueId), year=year, espn_s2=self.__espnS2, swid=self.__swid))
+                espn.League(
+                    league_id=int(self._leagueId),
+                    year=year,
+                    espn_s2=self.__espnS2,
+                    swid=self.__swid,
+                )
+            )
         return espnLeagueYears
 
     def getOwnerNames(self) -> dict[int, list[str]]:
@@ -60,21 +67,21 @@ class ESPNLeagueLoader(LeagueLoader):
                 yearToOwnerNamesMap[espnLeagueYear.year].append(espnTeam.owner)
         return yearToOwnerNamesMap
 
-    def loadLeague(self) -> League:
+    def loadLeague(self, validate: bool = True) -> League:
         espnLeagueYears = self.__getAllLeagues()
         league = self.__buildLeague(espnLeagueYears)
-        # validate new league
-        leagueValidation.runAllChecks(league)
+        if validate:
+            # validate new league
+            leagueValidation.runAllChecks(league)
         return league
 
     def __buildLeague(self, espnLeagues: list[ESPNLeague]) -> League:
         years = list()
-        leagueName = None
         for espnLeague in espnLeagues:
-            leagueName = espnLeague.settings.name if leagueName is None else leagueName
             self.__loadOwners(espnLeague.teams)
             years.append(self.__buildYear(espnLeague))
-        return League(name=leagueName, owners=self._owners, years=years)
+        # use the league name from the most recent year
+        return League(name=espnLeagues[-1].settings.name, owners=self._owners, years=years)
 
     def __loadOwners(self, espnTeams: list[ESPNTeam]) -> None:
         if self._owners is None:
@@ -93,7 +100,8 @@ class ESPNLeagueLoader(LeagueLoader):
 
     def __buildWeeks(self, espnLeague: ESPNLeague) -> list[Week]:
         weeks = list()
-        for i in range(espnLeague.current_week):  # current week seems to be the last week in the league
+        # current week seems to be the last week in the league
+        for i in range(espnLeague.current_week):
             # get each teams matchup for that week
             matchups = list()
             # to avoid adding matchups twice, we keep track of the ESPN team IDs that have already had a matchup added
@@ -102,7 +110,10 @@ class ESPNLeagueLoader(LeagueLoader):
                 # skip if we already have this team in a matchup
                 # OR
                 # this team is on a bye
-                if espnTeam.team_id in espnTeamIDsWithMatchups or espnTeam.outcomes[i] == self.__ESPN_BYE_OUTCOME:
+                if (
+                    espnTeam.team_id in espnTeamIDsWithMatchups
+                    or espnTeam.outcomes[i] == self.__ESPN_BYE_OUTCOME
+                ):
                     continue
                 # team A is *this* team
                 espnTeamA = espnTeam
@@ -111,25 +122,37 @@ class ESPNLeagueLoader(LeagueLoader):
                 # team B is their opponent
                 espnTeamB = espnTeam.schedule[i]
                 teamB = self.__espnTeamIdToTeamMap[espnTeam.schedule[i].team_id]
-                teamBScore = self.__getESPNTeamByESPNId(espnTeam.schedule[i].team_id, espnLeague.teams).scores[i]
+                teamBScore = self.__getESPNTeamByESPNId(
+                    espnTeam.schedule[i].team_id, espnLeague.teams
+                ).scores[i]
                 # figure out tiebreakers if there needs to be one
-                teamAHasTiebreaker = teamAScore == teamBScore and espnTeamA.outcomes[i] == self.__ESPN_WIN_OUTCOME
-                teamBHasTiebreaker = teamAScore == teamBScore and espnTeamB.outcomes[i] == self.__ESPN_WIN_OUTCOME
+                teamAHasTiebreaker = (
+                    teamAScore == teamBScore and espnTeamA.outcomes[i] == self.__ESPN_WIN_OUTCOME
+                )
+                teamBHasTiebreaker = (
+                    teamAScore == teamBScore and espnTeamB.outcomes[i] == self.__ESPN_WIN_OUTCOME
+                )
                 matchupType = self.__getMatchupType(espnLeague, i + 1, espnTeamA.team_id)
-                matchups.append(Matchup(teamAId=teamA.id,
-                                        teamBId=teamB.id,
-                                        teamAScore=teamAScore,
-                                        teamBScore=teamBScore,
-                                        teamAHasTiebreaker=teamAHasTiebreaker,
-                                        teamBHasTiebreaker=teamBHasTiebreaker,
-                                        matchupType=matchupType))
+                matchups.append(
+                    Matchup(
+                        teamAId=teamA.id,
+                        teamBId=teamB.id,
+                        teamAScore=teamAScore,
+                        teamBScore=teamBScore,
+                        teamAHasTiebreaker=teamAHasTiebreaker,
+                        teamBHasTiebreaker=teamBHasTiebreaker,
+                        matchupType=matchupType,
+                    )
+                )
                 espnTeamIDsWithMatchups.append(espnTeam.team_id)
                 espnTeamIDsWithMatchups.append(espnTeam.schedule[i].team_id)
             if len(matchups) > 0:
                 weeks.append(Week(weekNumber=i + 1, matchups=matchups))
         return weeks
 
-    def __getMatchupType(self, espnLeague: ESPNLeague, weekNumber: int, espnTeamId: int) -> MatchupType:
+    def __getMatchupType(
+        self, espnLeague: ESPNLeague, weekNumber: int, espnTeamId: int
+    ) -> MatchupType:
         isPlayoffWeek = weekNumber > espnLeague.settings.reg_season_count
         if isPlayoffWeek:
             # figure out if this team made the playoffs
@@ -138,7 +161,9 @@ class ESPNLeagueLoader(LeagueLoader):
             if playoffTeamCount >= espnTeam.standing:
                 # this team made the playoffs
                 # figure out if this is the last week of playoffs (the championship week)
-                numberOfPlayoffWeeks = self.__TEAMS_IN_PLAYOFFS_TO_PLAYOFF_WEEK_COUNT_MAP[playoffTeamCount]
+                numberOfPlayoffWeeks = self.__TEAMS_IN_PLAYOFFS_TO_PLAYOFF_WEEK_COUNT_MAP[
+                    playoffTeamCount
+                ]
                 # TODO: Raise specific exception here if not found in map
                 if weekNumber == espnLeague.settings.reg_season_count + numberOfPlayoffWeeks:
                     # this is the championship week
