@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from typing import Optional
 
 from leeger.exception import DoesNotExistException
 from leeger.model.abstract.UniqueId import UniqueId
@@ -16,7 +17,7 @@ class Year(UniqueId, JSONSerializable, JSONDeserializable):
     yearNumber: int
     teams: list[Team]
     weeks: list[Week]
-    yearSettings: YearSettings = None
+    yearSettings: Optional[YearSettings] = None
 
     def __post_init__(self):
         if self.yearSettings is None:
@@ -60,7 +61,7 @@ class Year(UniqueId, JSONSerializable, JSONDeserializable):
             "yearNumber": self.yearNumber,
             "teams": [team.toJson() for team in self.teams],
             "weeks": [week.toJson() for week in self.weeks],
-            "yearSettings": self.yearSettings.toJson()
+            "yearSettings": self.yearSettings.toJson(),
         }
 
     @staticmethod
@@ -71,9 +72,11 @@ class Year(UniqueId, JSONSerializable, JSONDeserializable):
         weeks = list()
         for weekDict in d["weeks"]:
             weeks.append(Week.fromJson(weekDict))
-        year = Year(yearNumber=d["yearNumber"],
-                    teams=teams,
-                    weeks=weeks,
-                    yearSettings=YearSettings.fromJson(d.get("yearSettings")))
+        year = Year(
+            yearNumber=d["yearNumber"],
+            teams=teams,
+            weeks=weeks,
+            yearSettings=YearSettings.fromJson(d.get("yearSettings")),
+        )
         year.id = d["id"]
         return year
