@@ -17,11 +17,13 @@ class MatchupNavigator:
         winningTeamId = None
         # team A won
         if (matchup.teamAScore > matchup.teamBScore) or (
-                matchup.teamAScore == matchup.teamBScore and matchup.teamAHasTiebreaker):
+            matchup.teamAScore == matchup.teamBScore and matchup.teamAHasTiebreaker
+        ):
             winningTeamId = matchup.teamAId
         # team B won
         elif (matchup.teamBScore > matchup.teamAScore) or (
-                matchup.teamAScore == matchup.teamBScore and matchup.teamBHasTiebreaker):
+            matchup.teamAScore == matchup.teamBScore and matchup.teamBHasTiebreaker
+        ):
             winningTeamId = matchup.teamBId
         return winningTeamId
 
@@ -33,13 +35,15 @@ class MatchupNavigator:
         """
         if len(matchups) == 0:
             raise ValueError(f"matchups cannot be an empty list.")
-        return Matchup(teamAId=matchups[0].teamAId,
-                       teamBId=matchups[0].teamBId,
-                       teamAScore=sum([matchup.teamAScore for matchup in matchups]),
-                       teamBScore=sum([matchup.teamBScore for matchup in matchups]),
-                       teamAHasTiebreaker=matchups[0].teamAHasTiebreaker,
-                       teamBHasTiebreaker=matchups[0].teamBHasTiebreaker,
-                       matchupType=matchups[0].matchupType)
+        return Matchup(
+            teamAId=matchups[0].teamAId,
+            teamBId=matchups[0].teamBId,
+            teamAScore=sum([matchup.teamAScore for matchup in matchups]),
+            teamBScore=sum([matchup.teamBScore for matchup in matchups]),
+            teamAHasTiebreaker=matchups[0].teamAHasTiebreaker,
+            teamBHasTiebreaker=matchups[0].teamBHasTiebreaker,
+            matchupType=matchups[0].matchupType,
+        )
 
     @classmethod
     def getMedianScore(cls, matchups: list[Matchup]) -> float:
