@@ -9,12 +9,16 @@ from test.helper.prototypes import getNDefaultOwnersAndTeams
 
 
 class TestSingleScoreYearCalculator(unittest.TestCase):
-
     def test_getMaxScore_happyPath(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
@@ -24,12 +28,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.2, teamBScore=6)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -66,23 +85,47 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMaxScore_onlyPostSeasonIsTrue(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
 
-        matchup4 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=10.2, teamBScore=20.2)
-        matchup5 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=30.2, teamBScore=40.2)
+        matchup4 = Matchup(
+            teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=10.2, teamBScore=20.2
+        )
+        matchup5 = Matchup(
+            teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=30.2, teamBScore=40.2
+        )
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=40.2, teamBScore=60)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -101,8 +144,13 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMaxScore_onlyRegularSeasonIsTrue(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
@@ -112,12 +160,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.2, teamBScore=6)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -136,8 +199,13 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMaxScore_onlyChampionshipIsTrue(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
@@ -147,12 +215,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.2, teamBScore=6)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -171,9 +254,16 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMaxScore_weekNumberStartGiven(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=10.1, teamBScore=20.1,
-                           matchupType=MatchupType.IGNORE)
-        matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=30.1, teamBScore=40.1)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=10.1,
+            teamBScore=20.1,
+            matchupType=MatchupType.IGNORE,
+        )
+        matchup2 = Matchup(
+            teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=30.1, teamBScore=40.1
+        )
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=40.1, teamBScore=50)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
 
@@ -182,12 +272,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.2, teamBScore=6)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -206,8 +311,13 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMaxScore_weekNumberEndGiven(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
@@ -217,12 +327,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.2, teamBScore=6)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -241,8 +366,13 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMaxScore_weekNumberStartGivenAndWeekNumberEndGiven(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
@@ -257,12 +387,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7)
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
-        matchup10 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=10.3, teamBScore=20.3,
-                            matchupType=MatchupType.PLAYOFF)
-        matchup11 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=30.3, teamBScore=40.3,
-                            matchupType=MatchupType.PLAYOFF)
-        matchup12 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=40.3, teamBScore=70,
-                            matchupType=MatchupType.CHAMPIONSHIP)
+        matchup10 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=10.3,
+            teamBScore=20.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup11 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=30.3,
+            teamBScore=40.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup12 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=40.3,
+            teamBScore=70,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week4 = Week(weekNumber=4, matchups=[matchup10, matchup11, matchup12])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -281,8 +426,13 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMinScore_happyPath(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
@@ -292,12 +442,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.2, teamBScore=6)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -334,23 +499,47 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMinScore_onlyPostSeasonIsTrue(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
 
-        matchup4 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=10.2, teamBScore=20.2)
-        matchup5 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=30.2, teamBScore=40.2)
+        matchup4 = Matchup(
+            teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=10.2, teamBScore=20.2
+        )
+        matchup5 = Matchup(
+            teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=30.2, teamBScore=40.2
+        )
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=40.2, teamBScore=60)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -369,8 +558,13 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMinScore_onlyRegularSeasonIsTrue(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
@@ -380,12 +574,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.2, teamBScore=6)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -404,8 +613,13 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMinScore_onlyChampionshipIsTrue(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
@@ -415,12 +629,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.2, teamBScore=6)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -439,9 +668,16 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMinScore_weekNumberStartGiven(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=10.1, teamBScore=20.1,
-                           matchupType=MatchupType.IGNORE)
-        matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=30.1, teamBScore=40.1)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=10.1,
+            teamBScore=20.1,
+            matchupType=MatchupType.IGNORE,
+        )
+        matchup2 = Matchup(
+            teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=30.1, teamBScore=40.1
+        )
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=40.1, teamBScore=50)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
 
@@ -450,12 +686,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.2, teamBScore=6)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -474,8 +725,13 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMinScore_weekNumberEndGiven(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
@@ -485,12 +741,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup6 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.2, teamBScore=6)
         week2 = Week(weekNumber=2, matchups=[matchup4, matchup5, matchup6])
 
-        matchup7 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.3, teamBScore=2.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup8 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.3, teamBScore=4.3,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup7 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.3,
+            teamBScore=2.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup8 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=3.3,
+            teamBScore=4.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup9 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=4.3,
+            teamBScore=7,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
@@ -509,8 +780,13 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
     def test_getMinScore_weekNumberStartGivenAndWeekNumberEndGiven(self):
         owners, teams = getNDefaultOwnersAndTeams(6)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.1,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.1,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=3.1, teamBScore=4.1)
         matchup3 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.1, teamBScore=5)
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2, matchup3])
@@ -525,12 +801,27 @@ class TestSingleScoreYearCalculator(unittest.TestCase):
         matchup9 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=4.3, teamBScore=7)
         week3 = Week(weekNumber=3, matchups=[matchup7, matchup8, matchup9])
 
-        matchup10 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=10.3, teamBScore=20.3,
-                            matchupType=MatchupType.PLAYOFF)
-        matchup11 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=30.3, teamBScore=40.3,
-                            matchupType=MatchupType.PLAYOFF)
-        matchup12 = Matchup(teamAId=teams[4].id, teamBId=teams[5].id, teamAScore=40.3, teamBScore=70,
-                            matchupType=MatchupType.CHAMPIONSHIP)
+        matchup10 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=10.3,
+            teamBScore=20.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup11 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=30.3,
+            teamBScore=40.3,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup12 = Matchup(
+            teamAId=teams[4].id,
+            teamBId=teams[5].id,
+            teamAScore=40.3,
+            teamBScore=70,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
         week4 = Week(weekNumber=4, matchups=[matchup10, matchup11, matchup12])
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
