@@ -18,7 +18,7 @@ class TestMatchup(unittest.TestCase):
             matchupType=MatchupType.PLAYOFF,
             teamAHasTiebreaker=True,
             teamBHasTiebreaker=False,
-            multiWeekMatchupId="id"
+            multiWeekMatchupId="id",
         )
 
         self.assertEqual("teamAId", matchup.teamAId)
@@ -31,12 +31,7 @@ class TestMatchup(unittest.TestCase):
         self.assertEqual("id", matchup.multiWeekMatchupId)
 
     def test_matchup_init_defaultValues_1(self):
-        matchup = Matchup(
-            teamAId="teamAId",
-            teamBId="teamBId",
-            teamAScore=1.1,
-            teamBScore=2.2
-        )
+        matchup = Matchup(teamAId="teamAId", teamBId="teamBId", teamAScore=1.1, teamBScore=2.2)
 
         self.assertEqual("teamAId", matchup.teamAId)
         self.assertEqual("teamBId", matchup.teamBId)
@@ -54,7 +49,7 @@ class TestMatchup(unittest.TestCase):
             teamAScore=1.1,
             teamBScore=2.2,
             teamAHasTiebreaker=None,
-            teamBHasTiebreaker=None
+            teamBHasTiebreaker=None,
         )
 
         self.assertEqual("teamAId", matchup.teamAId)
@@ -74,61 +69,73 @@ class TestMatchup(unittest.TestCase):
                 teamAScore=1.1,
                 teamBScore=2.2,
                 teamAHasTiebreaker=True,
-                teamBHasTiebreaker=True
+                teamBHasTiebreaker=True,
             )
-        self.assertEqual("Team A and Team B cannot both have the tiebreaker.", str(context.exception))
+        self.assertEqual(
+            "Team A and Team B cannot both have the tiebreaker.", str(context.exception)
+        )
 
     def test_matchup_eq_equal(self):
         # create Matchup 1
         _, teams_1 = getNDefaultOwnersAndTeams(2)
-        matchup_1 = Matchup(teamAId=teams_1[0].id,
-                            teamBId=teams_1[1].id,
-                            teamAScore=1.1,
-                            teamBScore=2.2,
-                            multiWeekMatchupId="1",
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_1 = Matchup(
+            teamAId=teams_1[0].id,
+            teamBId=teams_1[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            multiWeekMatchupId="1",
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
 
         # create Matchup 2
         _, teams_2 = getNDefaultOwnersAndTeams(2)
-        matchup_2 = Matchup(teamAId=teams_2[0].id,
-                            teamBId=teams_2[1].id,
-                            teamAScore=1.1,
-                            teamBScore=2.2,
-                            multiWeekMatchupId="1",
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_2 = Matchup(
+            teamAId=teams_2[0].id,
+            teamBId=teams_2[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            multiWeekMatchupId="1",
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
 
         self.assertEqual(matchup_1, matchup_2)
 
     def test_matchup_eq_notEqual(self):
         # create Matchup 1
         _, teams_1 = getNDefaultOwnersAndTeams(2)
-        matchup_1 = Matchup(teamAId=teams_1[0].id,
-                            teamBId=teams_1[1].id,
-                            teamAScore=1.1,
-                            teamBScore=2.2,
-                            multiWeekMatchupId="1",
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_1 = Matchup(
+            teamAId=teams_1[0].id,
+            teamBId=teams_1[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            multiWeekMatchupId="1",
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
 
         # create Matchup 2
         _, teams_2 = getNDefaultOwnersAndTeams(2)
-        matchup_2 = Matchup(teamAId=teams_2[0].id,
-                            teamBId=teams_2[1].id,
-                            teamAScore=1.1,
-                            teamBScore=2.2,
-                            multiWeekMatchupId="1",
-                            matchupType=MatchupType.PLAYOFF)
+        matchup_2 = Matchup(
+            teamAId=teams_2[0].id,
+            teamBId=teams_2[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            multiWeekMatchupId="1",
+            matchupType=MatchupType.PLAYOFF,
+        )
 
         self.assertNotEqual(matchup_1, matchup_2)
 
     def test_matchup_toJson(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup = Matchup(teamAId=teams[0].id,
-                          teamBId=teams[1].id,
-                          teamAScore=1.1,
-                          teamBScore=2.2,
-                          multiWeekMatchupId="1",
-                          matchupType=MatchupType.REGULAR_SEASON)
+        matchup = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            multiWeekMatchupId="1",
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
         matchupJson = matchup.toJson()
 
         self.assertIsInstance(matchupJson, dict)
@@ -144,12 +151,14 @@ class TestMatchup(unittest.TestCase):
     def test_splitToPerformances_happyPath(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup = Matchup(teamAId=teams[0].id,
-                          teamBId=teams[1].id,
-                          teamAScore=1.1,
-                          teamBScore=2.2,
-                          multiWeekMatchupId="1",
-                          matchupType=MatchupType.REGULAR_SEASON)
+        matchup = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            multiWeekMatchupId="1",
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
 
         responseA, responseB = matchup.splitToPerformances()
 
@@ -165,12 +174,14 @@ class TestMatchup(unittest.TestCase):
         self.assertEqual("1", responseB.multiWeekMatchupId)
 
     def test_getPerformanceForTeamId_happyPath(self):
-        matchup = Matchup(teamAId="1",
-                          teamBId="2",
-                          teamAScore=1.1,
-                          teamBScore=2.2,
-                          multiWeekMatchupId="1",
-                          matchupType=MatchupType.REGULAR_SEASON)
+        matchup = Matchup(
+            teamAId="1",
+            teamBId="2",
+            teamAScore=1.1,
+            teamBScore=2.2,
+            multiWeekMatchupId="1",
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
 
         response = matchup.getPerformanceForTeamId("1")
 
@@ -181,12 +192,14 @@ class TestMatchup(unittest.TestCase):
         self.assertEqual(MatchupType.REGULAR_SEASON, response.matchupType)
 
     def test_getPerformanceForTeamId_teamIdNotInMatchup_raisesException(self):
-        matchup = Matchup(teamAId="1",
-                          teamBId="2",
-                          teamAScore=1.1,
-                          teamBScore=2.2,
-                          multiWeekMatchupId="1",
-                          matchupType=MatchupType.REGULAR_SEASON)
+        matchup = Matchup(
+            teamAId="1",
+            teamBId="2",
+            teamAScore=1.1,
+            teamBScore=2.2,
+            multiWeekMatchupId="1",
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
 
         with self.assertRaises(DoesNotExistException) as context:
             matchup.getPerformanceForTeamId("3")
@@ -195,12 +208,14 @@ class TestMatchup(unittest.TestCase):
     def test_matchup_fromJson(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup = Matchup(teamAId=teams[0].id,
-                          teamBId=teams[1].id,
-                          teamAScore=1.1,
-                          teamBScore=2.2,
-                          multiWeekMatchupId="1",
-                          matchupType=MatchupType.REGULAR_SEASON)
+        matchup = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            multiWeekMatchupId="1",
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
         matchupJson = matchup.toJson()
         matchupDerived = Matchup.fromJson(matchupJson)
         self.assertEqual(matchup, matchupDerived)
