@@ -10,8 +10,12 @@ from test.helper.prototypes import getNDefaultOwnersAndTeams
 class TestWeek(unittest.TestCase):
     def test_week_init(self):
         matchup1 = Matchup(teamAId="", teamBId="", teamAScore=0, teamBScore=0)
-        matchup2 = Matchup(teamAId="", teamBId="", teamAScore=0, teamBScore=0, matchupType=MatchupType.PLAYOFF)
-        matchup3 = Matchup(teamAId="", teamBId="", teamAScore=0, teamBScore=0, matchupType=MatchupType.CHAMPIONSHIP)
+        matchup2 = Matchup(
+            teamAId="", teamBId="", teamAScore=0, teamBScore=0, matchupType=MatchupType.PLAYOFF
+        )
+        matchup3 = Matchup(
+            teamAId="", teamBId="", teamAScore=0, teamBScore=0, matchupType=MatchupType.CHAMPIONSHIP
+        )
         week1 = Week(weekNumber=1, matchups=[matchup1])
         week2 = Week(weekNumber=2, matchups=[matchup2])
         week3 = Week(weekNumber=3, matchups=[matchup3])
@@ -31,8 +35,13 @@ class TestWeek(unittest.TestCase):
     def test_isPlayoffWeek_weekHasPlayoffMatchups_returnsTrue(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.PLAYOFF)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
 
@@ -44,8 +53,13 @@ class TestWeek(unittest.TestCase):
     def test_isPlayoffWeek_weekDoesNotHavePlayoffMatchups_returnsFalse(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.REGULAR_SEASON)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
 
@@ -57,8 +71,13 @@ class TestWeek(unittest.TestCase):
     def test_isChampionshipWeek_weekHasAChampionshipMatchup_returnsTrue(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
 
@@ -73,8 +92,13 @@ class TestWeek(unittest.TestCase):
     def test_isChampionshipWeek_weekDoesNotHaveAnyChampionshipMatchups_returnsFalse(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.REGULAR_SEASON)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
 
@@ -86,10 +110,20 @@ class TestWeek(unittest.TestCase):
     def test_isRegularSeasonWeek_weekHasAllRegularSeasonMatchups_returnsTrue(self):
         owners, teams = getNDefaultOwnersAndTeams(4)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.REGULAR_SEASON)
-        matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.IGNORE)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
+        matchup2 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.IGNORE,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2])
 
@@ -101,10 +135,20 @@ class TestWeek(unittest.TestCase):
     def test_isChampionshipWeek_weekHasANonRegularSeasonMatchup_returnsFalse(self):
         owners, teams = getNDefaultOwnersAndTeams(4)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.REGULAR_SEASON)
-        matchup2 = Matchup(teamAId=teams[2].id, teamBId=teams[3].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.PLAYOFF)
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
+        matchup2 = Matchup(
+            teamAId=teams[2].id,
+            teamBId=teams[3].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1, matchup2])
 
@@ -116,14 +160,24 @@ class TestWeek(unittest.TestCase):
     def test_week_eq_equal(self):
         # create Week 1
         _, teams_1 = getNDefaultOwnersAndTeams(2)
-        matchup_1 = Matchup(teamAId=teams_1[0].id, teamBId=teams_1[1].id, teamAScore=1.1, teamBScore=2.2,
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_1 = Matchup(
+            teamAId=teams_1[0].id,
+            teamBId=teams_1[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
         week_1 = Week(weekNumber=1, matchups=[matchup_1])
 
         # create Week 2
         _, teams_2 = getNDefaultOwnersAndTeams(2)
-        matchup_2 = Matchup(teamAId=teams_2[0].id, teamBId=teams_2[1].id, teamAScore=1.1, teamBScore=2.2,
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_2 = Matchup(
+            teamAId=teams_2[0].id,
+            teamBId=teams_2[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
         week_2 = Week(weekNumber=1, matchups=[matchup_2])
 
         self.assertEqual(week_1, week_2)
@@ -131,14 +185,24 @@ class TestWeek(unittest.TestCase):
     def test_week_eq_notEqual(self):
         # create Week 1
         _, teams_1 = getNDefaultOwnersAndTeams(2)
-        matchup_1 = Matchup(teamAId=teams_1[0].id, teamBId=teams_1[1].id, teamAScore=1.1, teamBScore=2.2,
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_1 = Matchup(
+            teamAId=teams_1[0].id,
+            teamBId=teams_1[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
         week_1 = Week(weekNumber=1, matchups=[matchup_1])
 
         # create Week 2
         _, teams_2 = getNDefaultOwnersAndTeams(2)
-        matchup_2 = Matchup(teamAId=teams_2[0].id, teamBId=teams_2[1].id, teamAScore=1.1, teamBScore=2.2,
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_2 = Matchup(
+            teamAId=teams_2[0].id,
+            teamBId=teams_2[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
         week_2 = Week(weekNumber=2, matchups=[matchup_2])
 
         self.assertNotEqual(week_1, week_2)
@@ -146,8 +210,13 @@ class TestWeek(unittest.TestCase):
     def test_week_toJson(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup_1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.2,
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
         week = Week(weekNumber=1, matchups=[matchup_1])
         weekJson = week.toJson()
 
@@ -165,8 +234,13 @@ class TestWeek(unittest.TestCase):
     def test_getMatchupWithTeamId_happyPath(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup_1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.2,
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
         week = Week(weekNumber=1, matchups=[matchup_1])
 
         response = week.getMatchupWithTeamId(teams[0].id)
@@ -175,19 +249,31 @@ class TestWeek(unittest.TestCase):
     def test_getMatchupWithTeamId_teamIdNotInMatchups_raisesException(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup_1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.2,
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
         week = Week(weekNumber=1, matchups=[matchup_1])
 
         with self.assertRaises(DoesNotExistException) as context:
             week.getMatchupWithTeamId("bad ID")
-        self.assertEqual("Week does not have a matchup with team ID 'bad ID'.", str(context.exception))
+        self.assertEqual(
+            "Week does not have a matchup with team ID 'bad ID'.", str(context.exception)
+        )
 
     def test_week_fromJson(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup_1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1.1, teamBScore=2.2,
-                            matchupType=MatchupType.REGULAR_SEASON)
+        matchup_1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1.1,
+            teamBScore=2.2,
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
         week = Week(weekNumber=1, matchups=[matchup_1])
         weekJson = week.toJson()
         weekDerived = Week.fromJson(weekJson)
