@@ -21,19 +21,37 @@ class TestYearNavigator(unittest.TestCase):
         a_team2 = Team(ownerId=owner2.id, name="2")
 
         a_matchup1 = Matchup(teamAId=a_team1.id, teamBId=a_team2.id, teamAScore=1, teamBScore=2)
-        a_matchup2 = Matchup(teamAId=a_team1.id, teamBId=a_team2.id, teamAScore=1, teamBScore=2,
-                             matchupType=MatchupType.PLAYOFF)
-        a_matchup3 = Matchup(teamAId=a_team1.id, teamBId=a_team2.id, teamAScore=1, teamBScore=1,
-                             teamAHasTiebreaker=True, matchupType=MatchupType.PLAYOFF)
-        a_matchup4 = Matchup(teamAId=a_team1.id, teamBId=a_team2.id, teamAScore=1, teamBScore=2,
-                             matchupType=MatchupType.CHAMPIONSHIP)
+        a_matchup2 = Matchup(
+            teamAId=a_team1.id,
+            teamBId=a_team2.id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        a_matchup3 = Matchup(
+            teamAId=a_team1.id,
+            teamBId=a_team2.id,
+            teamAScore=1,
+            teamBScore=1,
+            teamAHasTiebreaker=True,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        a_matchup4 = Matchup(
+            teamAId=a_team1.id,
+            teamBId=a_team2.id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
 
         a_week1 = Week(weekNumber=1, matchups=[a_matchup1])
         a_week2 = Week(weekNumber=2, matchups=[a_matchup2])
         a_week3 = Week(weekNumber=3, matchups=[a_matchup3])
         a_week4 = Week(weekNumber=4, matchups=[a_matchup4])
 
-        a_year = Year(yearNumber=2000, teams=[a_team1, a_team2], weeks=[a_week1, a_week2, a_week3, a_week4])
+        a_year = Year(
+            yearNumber=2000, teams=[a_team1, a_team2], weeks=[a_week1, a_week2, a_week3, a_week4]
+        )
 
         response = YearNavigator.getAllTeamIds(a_year)
 
@@ -61,7 +79,9 @@ class TestYearNavigator(unittest.TestCase):
         self.assertEqual(2, response[teams[0].id])
         self.assertEqual(2, response[teams[1].id])
 
-    def test_getNumberOfGamesPlayed_countLeagueMedianGamesAsTwoGames_countsLeagueMedianGamesAsTwoGames(self):
+    def test_getNumberOfGamesPlayed_countLeagueMedianGamesAsTwoGames_countsLeagueMedianGamesAsTwoGames(
+        self,
+    ):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
         matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
@@ -74,18 +94,34 @@ class TestYearNavigator(unittest.TestCase):
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2], yearSettings=yearSettings)
 
         yearFilters = YearFilters(weekNumberStart=1, weekNumberEnd=2)
-        response = YearNavigator.getNumberOfGamesPlayed(year, yearFilters, countLeagueMedianGamesAsTwoGames=True)
+        response = YearNavigator.getNumberOfGamesPlayed(
+            year, yearFilters, countLeagueMedianGamesAsTwoGames=True
+        )
 
         self.assertIsInstance(response, dict)
         self.assertEqual(2, len(response.keys()))
         self.assertEqual(4, response[teams[0].id])
         self.assertEqual(4, response[teams[1].id])
 
-    def test_getNumberOfGamesPlayed_countMultiWeekMatchupsAsOneGameIsTrue_countsMultiWeekMatchupsAsOneGame(self):
+    def test_getNumberOfGamesPlayed_countMultiWeekMatchupsAsOneGameIsTrue_countsMultiWeekMatchupsAsOneGame(
+        self,
+    ):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
-        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
+        matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
         week2 = Week(weekNumber=2, matchups=[matchup2])
@@ -93,18 +129,34 @@ class TestYearNavigator(unittest.TestCase):
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2])
 
         yearFilters = YearFilters(weekNumberStart=1, weekNumberEnd=2)
-        response = YearNavigator.getNumberOfGamesPlayed(year, yearFilters, countMultiWeekMatchupsAsOneGame=True)
+        response = YearNavigator.getNumberOfGamesPlayed(
+            year, yearFilters, countMultiWeekMatchupsAsOneGame=True
+        )
 
         self.assertIsInstance(response, dict)
         self.assertEqual(2, len(response.keys()))
         self.assertEqual(1, response[teams[0].id])
         self.assertEqual(1, response[teams[1].id])
 
-    def test_getNumberOfGamesPlayed_countMultiWeekMatchupsAsOneGameIsFalse_countsMultiWeekMatchupsAsMultipleGames(self):
+    def test_getNumberOfGamesPlayed_countMultiWeekMatchupsAsOneGameIsFalse_countsMultiWeekMatchupsAsMultipleGames(
+        self,
+    ):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
-        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
+        matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
         week2 = Week(weekNumber=2, matchups=[matchup2])
@@ -112,7 +164,9 @@ class TestYearNavigator(unittest.TestCase):
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2])
 
         yearFilters = YearFilters(weekNumberStart=1, weekNumberEnd=2)
-        response = YearNavigator.getNumberOfGamesPlayed(year, yearFilters, countMultiWeekMatchupsAsOneGame=False)
+        response = YearNavigator.getNumberOfGamesPlayed(
+            year, yearFilters, countMultiWeekMatchupsAsOneGame=False
+        )
 
         self.assertIsInstance(response, dict)
         self.assertEqual(2, len(response.keys()))
@@ -123,10 +177,20 @@ class TestYearNavigator(unittest.TestCase):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
         matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
-        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup3 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
         week2 = Week(weekNumber=2, matchups=[matchup2])
@@ -134,8 +198,7 @@ class TestYearNavigator(unittest.TestCase):
 
         year = Year(yearNumber=2000, teams=teams, weeks=[week1, week2, week3])
 
-        yearFilters = YearFilters(weekNumberStart=1, weekNumberEnd=3,
-                                  onlyPostSeason=True)
+        yearFilters = YearFilters(weekNumberStart=1, weekNumberEnd=3, onlyPostSeason=True)
         response = YearNavigator.getNumberOfGamesPlayed(year, yearFilters)
 
         self.assertIsInstance(response, dict)
@@ -147,10 +210,20 @@ class TestYearNavigator(unittest.TestCase):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
         matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
-        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup3 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
         week2 = Week(weekNumber=2, matchups=[matchup2])
@@ -170,10 +243,20 @@ class TestYearNavigator(unittest.TestCase):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
         matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
-        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup3 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
         week2 = Week(weekNumber=2, matchups=[matchup2])
@@ -193,10 +276,20 @@ class TestYearNavigator(unittest.TestCase):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
         matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
-        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup3 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
         week2 = Week(weekNumber=2, matchups=[matchup2])
@@ -216,12 +309,27 @@ class TestYearNavigator(unittest.TestCase):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
         matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
-        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.PLAYOFF)
-        matchup4 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                           matchupType=MatchupType.CHAMPIONSHIP)
+        matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup3 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        matchup4 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
         week2 = Week(weekNumber=2, matchups=[matchup2])
@@ -242,8 +350,13 @@ class TestYearNavigator(unittest.TestCase):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
         matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
-        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=3, teamBScore=4,
-                           matchupType=MatchupType.IGNORE)
+        matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=3,
+            teamBScore=4,
+            matchupType=MatchupType.IGNORE,
+        )
         matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=5, teamBScore=6)
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
@@ -261,8 +374,20 @@ class TestYearNavigator(unittest.TestCase):
     def test_getAllScoresInYear_simplifyMultiWeekMatchupsIsTrue(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
-        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=3, teamBScore=4, multiWeekMatchupId="1")
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
+        matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=3,
+            teamBScore=4,
+            multiWeekMatchupId="1",
+        )
         matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=5, teamBScore=6)
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
@@ -280,9 +405,27 @@ class TestYearNavigator(unittest.TestCase):
     def test_getAllMultiWeekMatchups_happyPath(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2, multiWeekMatchupId="1")
-        matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=3, teamBScore=4, multiWeekMatchupId="1")
-        matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=5, teamBScore=6, multiWeekMatchupId="1")
+        matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
+        matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=3,
+            teamBScore=4,
+            multiWeekMatchupId="1",
+        )
+        matchup3 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=5,
+            teamBScore=6,
+            multiWeekMatchupId="1",
+        )
 
         week1 = Week(weekNumber=1, matchups=[matchup1])
         week2 = Week(weekNumber=2, matchups=[matchup2])
@@ -320,22 +463,45 @@ class TestYearNavigator(unittest.TestCase):
 
     def test_getAllMultiWeekMatchups_includeMultiWeekMatchupsIsFalse_raisesException(self):
         with self.assertRaises(ValueError) as context:
-            YearNavigator.getAllMultiWeekMatchups(None, YearFilters(weekNumberStart=1,
-                                                                    weekNumberEnd=3,
-                                                                    onlyRegularSeason=True,
-                                                                    includeMultiWeekMatchups=False))
-        self.assertEqual("Multi-Week matchups must be included in this calculation.", str(context.exception))
+            YearNavigator.getAllMultiWeekMatchups(
+                None,
+                YearFilters(
+                    weekNumberStart=1,
+                    weekNumberEnd=3,
+                    onlyRegularSeason=True,
+                    includeMultiWeekMatchups=False,
+                ),
+            )
+        self.assertEqual(
+            "Multi-Week matchups must be included in this calculation.", str(context.exception)
+        )
 
     def test_getAllMatchupsInYear_noFilterGiven_happyPath(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
         a_matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
-        a_matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             matchupType=MatchupType.PLAYOFF)
-        a_matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=1,
-                             teamAHasTiebreaker=True, matchupType=MatchupType.PLAYOFF)
-        a_matchup4 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             matchupType=MatchupType.CHAMPIONSHIP)
+        a_matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        a_matchup3 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=1,
+            teamAHasTiebreaker=True,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        a_matchup4 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
 
         a_week1 = Week(weekNumber=1, matchups=[a_matchup1])
         a_week2 = Week(weekNumber=2, matchups=[a_matchup2])
@@ -358,10 +524,21 @@ class TestYearNavigator(unittest.TestCase):
 
         a_matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
         a_matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
-        a_matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=1,
-                             teamAHasTiebreaker=True, matchupType=MatchupType.PLAYOFF)
-        a_matchup4 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             matchupType=MatchupType.CHAMPIONSHIP)
+        a_matchup3 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=1,
+            teamAHasTiebreaker=True,
+            matchupType=MatchupType.PLAYOFF,
+        )
+        a_matchup4 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.CHAMPIONSHIP,
+        )
 
         a_week1 = Week(weekNumber=1, matchups=[a_matchup1])
         a_week2 = Week(weekNumber=2, matchups=[a_matchup2])
@@ -370,8 +547,9 @@ class TestYearNavigator(unittest.TestCase):
 
         a_year = Year(yearNumber=2000, teams=teams, weeks=[a_week1, a_week2, a_week3, a_week4])
 
-        response = YearNavigator.getAllMatchupsInYear(a_year, YearFilters(weekNumberStart=2, weekNumberEnd=3,
-                                                                          onlyPostSeason=True))
+        response = YearNavigator.getAllMatchupsInYear(
+            a_year, YearFilters(weekNumberStart=2, weekNumberEnd=3, onlyPostSeason=True)
+        )
 
         self.assertIsInstance(response, list)
         self.assertEqual(1, len(response))
@@ -380,10 +558,20 @@ class TestYearNavigator(unittest.TestCase):
     def test_getAllMatchupsInYear_filterGiven_includeMultiWeekMatchupsIsTrue_happyPath(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        a_matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             multiWeekMatchupId="1")
-        a_matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             multiWeekMatchupId="1")
+        a_matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
+        a_matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
         a_matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
 
         a_week1 = Week(weekNumber=1, matchups=[a_matchup1])
@@ -392,10 +580,15 @@ class TestYearNavigator(unittest.TestCase):
 
         a_year = Year(yearNumber=2000, teams=teams, weeks=[a_week1, a_week2, a_week3])
 
-        response = YearNavigator.getAllMatchupsInYear(a_year, YearFilters(weekNumberStart=1,
-                                                                          weekNumberEnd=3,
-                                                                          onlyRegularSeason=True,
-                                                                          includeMultiWeekMatchups=True))
+        response = YearNavigator.getAllMatchupsInYear(
+            a_year,
+            YearFilters(
+                weekNumberStart=1,
+                weekNumberEnd=3,
+                onlyRegularSeason=True,
+                includeMultiWeekMatchups=True,
+            ),
+        )
 
         self.assertIsInstance(response, list)
         self.assertEqual(3, len(response))
@@ -406,10 +599,20 @@ class TestYearNavigator(unittest.TestCase):
     def test_getAllMatchupsInYear_filterGiven_includeMultiWeekMatchupsIsFalse_happyPath(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        a_matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             multiWeekMatchupId="1")
-        a_matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             multiWeekMatchupId="1")
+        a_matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
+        a_matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
         a_matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
 
         a_week1 = Week(weekNumber=1, matchups=[a_matchup1])
@@ -418,10 +621,15 @@ class TestYearNavigator(unittest.TestCase):
 
         a_year = Year(yearNumber=2000, teams=teams, weeks=[a_week1, a_week2, a_week3])
 
-        response = YearNavigator.getAllMatchupsInYear(a_year, YearFilters(weekNumberStart=1,
-                                                                          weekNumberEnd=3,
-                                                                          onlyRegularSeason=True,
-                                                                          includeMultiWeekMatchups=False))
+        response = YearNavigator.getAllMatchupsInYear(
+            a_year,
+            YearFilters(
+                weekNumberStart=1,
+                weekNumberEnd=3,
+                onlyRegularSeason=True,
+                includeMultiWeekMatchups=False,
+            ),
+        )
 
         self.assertIsInstance(response, list)
         self.assertEqual(1, len(response))
@@ -430,10 +638,20 @@ class TestYearNavigator(unittest.TestCase):
     def test_getAllSimplifiedMatchupsInYear_noFilterGiven_happyPath(self):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        a_matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             multiWeekMatchupId="1")
-        a_matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             multiWeekMatchupId="1")
+        a_matchup1 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
+        a_matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
         a_matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
 
         a_week1 = Week(weekNumber=1, matchups=[a_matchup1])
@@ -456,12 +674,27 @@ class TestYearNavigator(unittest.TestCase):
         owners, teams = getNDefaultOwnersAndTeams(2)
 
         a_matchup1 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
-        a_matchup2 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             multiWeekMatchupId="1")
-        a_matchup3 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             multiWeekMatchupId="1")
-        a_matchup4 = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2,
-                             matchupType=MatchupType.PLAYOFF)
+        a_matchup2 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
+        a_matchup3 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            multiWeekMatchupId="1",
+        )
+        a_matchup4 = Matchup(
+            teamAId=teams[0].id,
+            teamBId=teams[1].id,
+            teamAScore=1,
+            teamBScore=2,
+            matchupType=MatchupType.PLAYOFF,
+        )
 
         a_week1 = Week(weekNumber=1, matchups=[a_matchup1])
         a_week2 = Week(weekNumber=2, matchups=[a_matchup2])
@@ -469,10 +702,15 @@ class TestYearNavigator(unittest.TestCase):
 
         a_year = Year(yearNumber=2000, teams=teams, weeks=[a_week1, a_week2, a_week3])
 
-        response = YearNavigator.getAllSimplifiedMatchupsInYear(a_year, YearFilters(weekNumberStart=2,
-                                                                                    weekNumberEnd=3,
-                                                                                    onlyRegularSeason=True,
-                                                                                    includeMultiWeekMatchups=True))
+        response = YearNavigator.getAllSimplifiedMatchupsInYear(
+            a_year,
+            YearFilters(
+                weekNumberStart=2,
+                weekNumberEnd=3,
+                onlyRegularSeason=True,
+                includeMultiWeekMatchups=True,
+            ),
+        )
 
         self.assertIsInstance(response, list)
         self.assertEqual(1, len(response))
@@ -483,8 +721,15 @@ class TestYearNavigator(unittest.TestCase):
 
     def test_getAllSimplifiedMatchupsInYear_includeMultiWeekMatchupsIsFalse_raisesException(self):
         with self.assertRaises(ValueError) as context:
-            YearNavigator.getAllSimplifiedMatchupsInYear(None, YearFilters(weekNumberStart=1,
-                                                                           weekNumberEnd=3,
-                                                                           onlyRegularSeason=True,
-                                                                           includeMultiWeekMatchups=False))
-        self.assertEqual("Multi-Week matchups must be included in this calculation.", str(context.exception))
+            YearNavigator.getAllSimplifiedMatchupsInYear(
+                None,
+                YearFilters(
+                    weekNumberStart=1,
+                    weekNumberEnd=3,
+                    onlyRegularSeason=True,
+                    includeMultiWeekMatchups=False,
+                ),
+            )
+        self.assertEqual(
+            "Multi-Week matchups must be included in this calculation.", str(context.exception)
+        )
